@@ -652,7 +652,7 @@ void AgendaItem::dropEvent(QDropEvent *e)
     KContacts::Addressee::List list;
 
     if (KContacts::VCardDrag::fromMimeData(md, list)) {
-        for (const KContacts::Addressee &addressee : qAsConst(list)) {
+        for (const KContacts::Addressee &addressee : std::as_const(list)) {
             QString em(addressee.fullEmail());
             if (em.isEmpty()) {
                 em = addressee.realName();
@@ -1023,7 +1023,7 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
     }
 }
 
-void AgendaItem::drawRoundedRect(QPainter *p, const QRect &rect, bool selected, const QColor &bgColor, bool frame, int ft, bool roundTop, bool roundBottom)
+void AgendaItem::drawRoundedRect(QPainter *p, QRect rect, bool selected, const QColor &bgColor, bool frame, int ft, bool roundTop, bool roundBottom)
 {
     Q_UNUSED(ft)
     if (!mValid) {
