@@ -5,8 +5,7 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef EVENTVIEWS_TIMELABELS_H
-#define EVENTVIEWS_TIMELABELS_H
+#pragma once
 
 #include <QTimeZone>
 
@@ -66,7 +65,7 @@ private:
     Q_REQUIRED_RESULT QString cellToSuffix(const int cell) const;
 
     /** update the position of the marker showing the mouse position */
-    void mousePosChanged(const QPoint &pos);
+    void mousePosChanged(QPoint pos);
 
     void showMousePos();
     void hideMousePos();
@@ -84,4 +83,3 @@ private:
 };
 }
 
-#endif
