@@ -5,8 +5,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef EVENTVIEWS_MONTHGRAPHICSITEMS_H
-#define EVENTVIEWS_MONTHGRAPHICSITEMS_H
+#pragma once
 
 #include <QDate>
 #include <QGraphicsItem>
@@ -47,7 +46,7 @@ private:
 class MonthCell
 {
 public:
-    MonthCell(int id, const QDate &date, QGraphicsScene *scene);
+    MonthCell(int id, QDate date, QGraphicsScene *scene);
     ~MonthCell();
 
     /**
@@ -202,4 +201,3 @@ private:
 };
 }
 
-#endif
