@@ -265,11 +265,7 @@ KCalendarCore::DateList MonthView::selectedIncidenceDates() const
 QDateTime MonthView::selectionStart() const
 {
     if (d->scene->selectedCell()) {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        return QDateTime(d->scene->selectedCell()->date());
-#else
         return QDateTime(d->scene->selectedCell()->date().startOfDay());
-#endif
     } else {
         return QDateTime();
     }
@@ -413,11 +409,7 @@ void MonthView::showDates(const QDate &start, const QDate &end, const QDate &pre
 
 QPair<QDateTime, QDateTime> MonthView::actualDateRange(const QDateTime &start, const QDateTime &, const QDate &preferredMonth) const
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QDateTime dayOne = preferredMonth.isValid() ? QDateTime(preferredMonth) : start;
-#else
     QDateTime dayOne = preferredMonth.isValid() ? QDateTime(preferredMonth.startOfDay()) : start;
-#endif
 
     dayOne.setDate(QDate(dayOne.date().year(), dayOne.date().month(), 1));
     const int weekdayCol = (dayOne.date().dayOfWeek() + 7 - preferences()->firstDayOfWeek()) % 7;
@@ -527,7 +519,7 @@ void MonthView::reloadIncidences()
     std::sort(d->scene->mManagerList.begin(), d->scene->mManagerList.end(), MonthItem::greaterThan);
 
     // build each month's cell event list
-    for (MonthItem *manager : qAsConst(d->scene->mManagerList)) {
+    for (MonthItem *manager : std::as_const(d->scene->mManagerList)) {
         for (QDate date = manager->startDate(); date <= manager->endDate(); date = date.addDays(1)) {
             MonthCell *cell = d->scene->mMonthCellMap.value(date);
             if (cell) {
@@ -536,12 +528,12 @@ void MonthView::reloadIncidences()
         }
     }
 
-    for (MonthItem *manager : qAsConst(d->scene->mManagerList)) {
+    for (MonthItem *manager : std::as_const(d->scene->mManagerList)) {
         manager->updateMonthGraphicsItems();
         manager->updatePosition();
     }
 
-    for (MonthItem *manager : qAsConst(d->scene->mManagerList)) {
+    for (MonthItem *manager : std::as_const(d->scene->mManagerList)) {
         manager->updateGeometry();
     }
 
@@ -571,7 +563,7 @@ bool MonthView::usesFullWindow()
     return preferences()->fullViewMonth();
 }
 
-bool MonthView::isBusyDay(const QDate &day) const
+bool MonthView::isBusyDay(QDate day) const
 {
     return !d->mBusyDays[day].isEmpty();
 }
