@@ -296,11 +296,7 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
     d->mHintDate = QDateTime();
 
     auto grid = static_cast<KGantt::DateTimeGrid *>(d->mGantt->grid());
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    grid->setStartDateTime(QDateTime(start));
-#else
     grid->setStartDateTime(QDateTime(start.startOfDay()));
-#endif
     d->mLeftView->clear();
     uint index = 0;
     // item for every calendar
@@ -342,7 +338,7 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
     KCalendarCore::Event::List events;
     for (QDate day = start; day <= end; day = day.addDays(1)) {
         events = calendar()->events(day, QTimeZone::systemTimeZone(), KCalendarCore::EventSortStartDate, KCalendarCore::SortDirectionAscending);
-        for (const KCalendarCore::Event::Ptr &event : qAsConst(events)) {
+        for (const KCalendarCore::Event::Ptr &event : std::as_const(events)) {
             if (event->hasRecurrenceId()) {
                 continue;
             }
@@ -414,7 +410,7 @@ bool TimelineView::eventFilter(QObject *object, QEvent *event)
 
                 auto itemModel = qobject_cast<QStandardItemModel *>(d->mGantt->model());
 
-                auto *timelineItem = dynamic_cast<TimelineSubItem *>(itemModel->item(itemIndex.row(), itemIndex.column()));
+                auto timelineItem = dynamic_cast<TimelineSubItem *>(itemModel->item(itemIndex.row(), itemIndex.column()));
 
                 if (timelineItem) {
                     timelineItem->updateToolTip();
