@@ -4,8 +4,7 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef EVENTVIEWS_TIMELINEVIEW_P_H
-#define EVENTVIEWS_TIMELINEVIEW_P_H
+#pragma once
 
 #include "timelineview.h"
 
@@ -38,7 +37,7 @@ public:
 
     TimelineItem *calendarItemForIncidence(const Akonadi::Item &incidence);
     void insertIncidence(const Akonadi::Item &incidence);
-    void insertIncidence(const Akonadi::Item &incidence, const QDate &day);
+    void insertIncidence(const Akonadi::Item &incidence, QDate day);
     void removeIncidence(const Akonadi::Item &incidence);
 
 public Q_SLOTS:
@@ -46,7 +45,7 @@ public Q_SLOTS:
     void itemSelected(const QModelIndex &index);
     void itemDoubleClicked(const QModelIndex &index);
     void itemChanged(QStandardItem *item);
-    void contextMenuRequested(const QPoint &point);
+    void contextMenuRequested(QPoint point);
     void newEventWithHint(const QDateTime &);
 
 public:
@@ -63,4 +62,3 @@ private:
 };
 } // namespace EventViews
 
-#endif
